/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data SRM Util CPP: BringOnline Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: BringOnline.h,v 1.4 2008/03/13 16:32:44 ptedesco Exp $
 *  Release: $Name: glite-data-srm-util-cpp_R_2_0_0_1 $
 *
 */
#ifndef GLITE_DATA_SRM_UTIL_CPP_BRING_ONLINE_H_
#define GLITE_DATA_SRM_UTIL_CPP_BRING_ONLINE_H_

#include "glite/data/srm/util/details/AsynchRequest.h"
#include "glite/data/srm/util/details/RequestFactory.h"
#include "glite/data/srm/util/details/Final.h"
#include "glite/data/srm/util/details/FinalAsynch.h"

namespace glite {
namespace data  {
namespace srm   {
namespace util  {

/**
 * Abstract Class for BringOnline Asynchronous requests
 */	
class BringOnline : public details::AsynchRequest, public details::Final<BringOnline>, public details::FinalAsynch<BringOnline> {
public:	
    // -------------------------------------------------------------------------
    // Use the factory methods
    // -------------------------------------------------------------------------
    using details::Final<BringOnline>::create;
    using details::FinalAsynch<BringOnline>::create;

	// -------------------------------------------------------------------------
    // The BringOnline properties
    // -------------------------------------------------------------------------

    std::vector<BringOnlineFileRequest> files;
    FileStorageType::Value      desiredFileStorageType;
    int                         desiredTotalRequestTime;
    int                         desiredLifeTime;
    std::string                 targetSpaceToken;
    RetentionPolicyInfo         targetFileRetentionPolicyInfo;
    TransferParameters          transferParameters;
    int                         deferredStartTime;
    int                         remainingTotalRequestTime;
    int                         remainingDeferredStartTime;

protected:
    
    /**
     * Constructor
     */
    explicit BringOnline(Context::Ptr ctx):
        details::AsynchRequest(ctx),
        desiredFileStorageType(FileStorageType::DEFAULT),
        desiredTotalRequestTime(-1),
        desiredLifeTime(-1),
        remainingTotalRequestTime(-1),
        remainingDeferredStartTime(-1){}

    /**
     * Constructor
     */
    BringOnline(Context::Ptr ctx, const std::string& token):
        details::AsynchRequest(ctx,token),
        desiredFileStorageType(FileStorageType::DEFAULT),
        desiredTotalRequestTime(-1),
        desiredLifeTime(-1),
        remainingTotalRequestTime(-1),
        remainingDeferredStartTime(-1){}

private:
	/**
     * Default Constructor. Not Implemented
     */
    BringOnline();

private:
	
};

} // End namespace util
} // End namespace srm
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_SRM_UTIL_CPP_BRING_ONLINE_H_
