/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data SRM Util CPP: GetSpaceMetaData Class
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: GetSpaceMetaData.h,v 1.1 2008/03/13 16:32:44 ptedesco Exp $
 *  Release: $Name: glite-data-srm-util-cpp_R_2_0_0_1 $
 *
 */
#ifndef GLITE_DATA_SRM_UTIL_CPP_GET_SPACE_META_DATA_H_
#define GLITE_DATA_SRM_UTIL_CPP_GET_SPACE_META_DATA_H_

#include "glite/data/srm/util/details/SynchRequest.h"
#include "glite/data/srm/util/details/Final.h"

namespace glite {
namespace data  {
namespace srm   {
namespace util  {

/**
 * Abstract class for GetSpaceMetaData synchronous requests
 */ 
class GetSpaceMetaData : public details::SynchRequest, public details::Final<GetSpaceMetaData>{
public: 
    // -------------------------------------------------------------------------
    // Use the factory methods
    // -------------------------------------------------------------------------
    using details::Final<GetSpaceMetaData>::create;

    // -------------------------------------------------------------------------
    // The GetSpaceTokens properties
    // -------------------------------------------------------------------------

    /**
     * The tokens (input)
     */
    std::vector<std::string> tokens;
    
    /**
     * The spaces metadata (output)
     */
    std::vector<MetaDataSpace> spaceDetails;

protected:
    
    /**
     * Constructor
     */
    explicit GetSpaceMetaData(Context::Ptr ctx):details::SynchRequest(ctx){}

private:
    /**
     * Default constructor. Not implemented
     */
    GetSpaceMetaData();

};

} // End namespace util
} // End namespace srm
} // End namespace data
} // End namespace glite

#endif // GLITE_DATA_SRM_UTIL_CPP_GET_SPACE_META_DATA_H_
