/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data SRM Util CPP: PrepareToPut Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: PrepareToPut.h,v 1.5 2008/10/22 11:58:10 ptedesco Exp $
 *  Release: $Name: glite-data-srm-util-cpp_R_2_0_0_1 $
 *
 */
#ifndef GLITE_DATA_SRM_UTIL_CPP_PREPARE_TO_PUT_H_
#define GLITE_DATA_SRM_UTIL_CPP_PREPARE_TO_PUT_H_

#include <glite/data/srm/util/details/Request.h>
#include <glite/data/srm/util/details/AsynchRequest.h>
#include <glite/data/srm/util/details/Final.h>
#include <glite/data/srm/util/details/FinalAsynch.h>

namespace glite {
namespace data  {
namespace srm   {
namespace util  {

/**
 * Abstract Class for PrepareToPut Asynchronous requests
 */
class PrepareToPut : public details::AsynchRequest, public details::Final<PrepareToPut>, public details::FinalAsynch<PrepareToPut> {
public:
    
    // -------------------------------------------------------------------------
    // Use the factory methods
    // -------------------------------------------------------------------------
    using details::Final<PrepareToPut>::create;
    using details::FinalAsynch<PrepareToPut>::create;

    // -------------------------------------------------------------------------
    // The PrepareToPut properties
    // -------------------------------------------------------------------------

    std::vector<PutFileRequest> files;
    OverwriteMode::Value        overwriteOption;
    int                         desiredTotalRequestTime;
    int                         desiredPinLifeTime;
    int                         desiredFileLifeTime;
    FileStorageType::Value      desiredFileStorageType;
    std::string                 targetSpaceToken;
    RetentionPolicyInfo         targetFileRetentionPolicyInfo;
    TransferParameters          transferParameters;
    int                         remainingTotalRequestTime;
    // added in version 1.2.0
    int                         copyPinLifetime;

protected:

    /**
     * Constructor
     */
    explicit PrepareToPut(Context::Ptr ctx):
        details::AsynchRequest(ctx),
        overwriteOption(OverwriteMode::NEVER),
        desiredTotalRequestTime(-1),
        desiredPinLifeTime(-1),
        desiredFileLifeTime(-1),
        desiredFileStorageType(FileStorageType::DEFAULT),
        remainingTotalRequestTime(-1),
        copyPinLifetime(-1){}

    /**
     * Constructor
     */
    PrepareToPut(Context::Ptr ctx, const std::string& token):
        details::AsynchRequest(ctx,token),
        overwriteOption(OverwriteMode::NEVER),
        desiredTotalRequestTime(-1),
        desiredPinLifeTime(-1),
        desiredFileLifeTime(-1),
        desiredFileStorageType(FileStorageType::DEFAULT),
        remainingTotalRequestTime(-1){}

private:
    /**
     * Default Constructor. Not Implemented
     */
    PrepareToPut();

private:

};

} // End namespace util
} // End namespace srm
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_SRM_UTIL_CPP_PREPARE_TO_PUT_H_
