/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data SRM Util CPP: SrmCopy Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: SrmCopy.h,v 1.5 2008/10/15 07:07:29 ptedesco Exp $
 *  Release: $Name: glite-data-srm-util-cpp_R_2_0_0_1 $
 *
 */
#ifndef GLITE_DATA_SRM_UTIL_CPP_SRM_COPY_H_
#define GLITE_DATA_SRM_UTIL_CPP_SRM_COPY_H_

#include <glite/data/srm/util/details/Request.h>
#include <glite/data/srm/util/details/AsynchRequest.h>
#include <glite/data/srm/util/details/Final.h>
#include <glite/data/srm/util/details/FinalAsynch.h>

namespace glite {
namespace data  {
namespace srm   {
namespace util  {

/**
 * Abstract Class for SrmCopy Asynchronous requests
 */ 
class SrmCopy : public details::AsynchRequest, public details::Final<SrmCopy>, public details::FinalAsynch<SrmCopy> {
public: 
    // -------------------------------------------------------------------------
    // Use the factory methods
    // -------------------------------------------------------------------------
    using details::Final<SrmCopy>::create;
    using details::FinalAsynch<SrmCopy>::create;

    // -------------------------------------------------------------------------
    // The SrmCopy properties
    // -------------------------------------------------------------------------

    std::vector<CopyFileRequest> files;
    OverwriteMode::Value        overwriteOption;
    int                         desiredTotalRequestTime;
    int                         desiredTargetSURLLifeTime;
    FileStorageType::Value      targetFileStorageType;
    std::string                 targetSpaceToken;
    RetentionPolicyInfo         targetFileRetentionPolicyInfo;
    TransferParameters          transferParameters;
    int                         remainingTotalRequestTime;
    // added in version 1.2.0 
    std::string                 sourceSpaceToken;
    int                         copyPinLifetime;
protected:
    
    /**
     * Constructor
     */
    explicit SrmCopy(Context::Ptr ctx):
        details::AsynchRequest(ctx),
        overwriteOption(OverwriteMode::NEVER),
        desiredTotalRequestTime(-1),
        desiredTargetSURLLifeTime(-1),
        targetFileStorageType(FileStorageType::DEFAULT),
        remainingTotalRequestTime(-1),
        copyPinLifetime(-1){
    }

    /**
     * Constructor
     */
    SrmCopy(Context::Ptr ctx, const std::string& token):
        details::AsynchRequest(ctx,token),
        overwriteOption(OverwriteMode::NEVER),
        desiredTotalRequestTime(-1),
        desiredTargetSURLLifeTime(-1),
        targetFileStorageType(FileStorageType::DEFAULT),
        remainingTotalRequestTime(-1),
        copyPinLifetime(-1){
    }
private:
    /**
     * Default Constructor. Not Implemented
     */
    SrmCopy();

};

} // End namespace util
} // End namespace srm
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_SRM_UTIL_CPP_SRM_COPY_H_
