/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data SRM Util CPP: SrmLs Class
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: SrmLs.h,v 1.1 2008/03/18 17:07:29 ptedesco Exp $
 *  Release: $Name: glite-data-srm-util-cpp_R_2_0_0_1 $
 *
 */
#ifndef GLITE_DATA_SRM_UTIL_CPP_SRM_LS_H_
#define GLITE_DATA_SRM_UTIL_CPP_SRM_LS_H_

#include "glite/data/srm/util/details/AsynchRequest.h"
#include "glite/data/srm/util/details/Final.h"
#include "glite/data/srm/util/details/FinalAsynch.h"

namespace glite {
namespace data  {
namespace srm   {
namespace util  {

/**
 * Abstract Class for SrmLs synchronous requests.
 */ 
class SrmLs : 
    public details::AsynchRequest, 
    public details::Final<SrmLs>,
    public details::FinalAsynch<SrmLs>{
public: 
    // -------------------------------------------------------------------------
    // Use the factory methods
    // -------------------------------------------------------------------------
    using details::Final<SrmLs>::create;
    using details::FinalAsynch<SrmLs>::create;

    // -------------------------------------------------------------------------
    // The SrmLs properties
    // -------------------------------------------------------------------------
    
    // input 
    std::vector<std::string>    surls;
    ExtraInfo                   storageSystemInfo;
    FileStorageType::Value      fileStorageType;
    bool                        fullDetailedList;
    bool                        allLevelRecursive;
    int                         numOfLevels;
    int                         offset;
    int                         count;
        
    std::vector<MetaDataPathDetail2> details;

    /**
     * destructor
     */
    virtual ~SrmLs(){}    
    
protected:
    
    /**
     * Constructor
     */
    explicit SrmLs(Context::Ptr ctx):
        details::AsynchRequest(ctx),
        fileStorageType(FileStorageType::DEFAULT),
        fullDetailedList(false),
        allLevelRecursive(false),
        numOfLevels(1),
        offset(-1),
        count(-1){}

    /**
     * Constructor
     */
    SrmLs(Context::Ptr ctx, const std::string& token):
        details::AsynchRequest(ctx,token),
        fileStorageType(FileStorageType::DEFAULT),
        fullDetailedList(false),
        allLevelRecursive(false),
        numOfLevels(1),
        offset(-1),
        count(-1){}
            
private:
    /**
     * Default constructor. Not implemented
     */
    SrmLs();
    
};

} // End namespace util
} // End namespace srm
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_SRM_UTIL_CPP_SRM_LS_H_
