/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data SRM Util CPP: SrmStat Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: SrmStat.h,v 1.5 2008/10/22 11:58:10 ptedesco Exp $
 *  Release: $Name: glite-data-srm-util-cpp_R_2_0_0_1 $
 *
 */
#ifndef GLITE_DATA_SRM_UTIL_CPP_SRM_STAT_H_
#define GLITE_DATA_SRM_UTIL_CPP_SRM_STAT_H_

#include "glite/data/srm/util/details/SynchRequest.h"
#include "glite/data/srm/util/details/Final.h"

namespace glite {
namespace data  {
namespace srm   {
namespace util  {

/**
 * Abstract Class for SrmStat synchronous requests. In fact, this is not a real
 * SRM method, but rather a simplification of the SrmLs method in order to
 * be synchronous and not recursive
 */ 
class SrmStat : public details::SynchRequest, public details::Final<SrmStat>{
public: 
    // -------------------------------------------------------------------------
    // Use the factory methods
    // -------------------------------------------------------------------------
    using details::Final<SrmStat>::create;

    // -------------------------------------------------------------------------
    // The SrmStat properties
    // -------------------------------------------------------------------------
    std::vector<MetaDataPathDetail> files;
    FileStorageType::Value          fileStorageType;
    bool                            fullDetailedList;
    
    /**
     * destructor
     */
    virtual ~SrmStat(){}    
    
protected:
    
    /**
     * Constructor
     */
    explicit SrmStat(Context::Ptr ctx):
        details::SynchRequest(ctx),
        fileStorageType(FileStorageType::DEFAULT),
        fullDetailedList(true){}
    
private:
    /**
     * Default Constructor. Not Implemented
     */
    SrmStat();

private:
    
};

} // End namespace util
} // End namespace srm
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_SRM_UTIL_CPP_SRM_STAT_H_
