/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data SRM Util CPP: Final Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Final.h,v 1.3 2006/12/13 14:30:10 badino Exp $
 *  Release: $Name: glite-data-srm-util-cpp_R_2_0_0_1 $
 *
 */
#ifndef GLITE_DATA_SRM_UTIL_CPP_DETAILS_FINAL_H_
#define GLITE_DATA_SRM_UTIL_CPP_DETAILS_FINAL_H_

#include "glite/data/srm/util/Context.h"
#include "glite/data/srm/util/details/Request.h"
#include "glite/data/srm/util/details/RequestFactory.h"
#include <boost/utility.hpp>

namespace glite  {
namespace data   {
namespace srm    {
namespace util   {
namespace details{

/**
 * Final Class for SRM Requests
 */	
template <typename R>
class Final: boost::noncopyable {
public:	
    /**
     * Instantiate the Request
     */
	static R * create(Context::Ptr ctx) /*throw(LogicError)*/{ \
		return RequestFactory<R>::create(ctx); \
	};
    /**
     * Check if the Request is supported
     */
    static bool isSupported(Context::Ptr ctx) /*throw()*/{ \
		return RequestFactory<R>::isSupported(ctx); \
	};
};

} // End namespace details
} // End namespace util
} // End namespace srm
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_SRM_UTIL_CPP_DETAILS_FINAL_H_
