/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data SRM Util CPP: Synch Request Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: SynchRequest.h,v 1.3 2008/03/13 16:32:45 ptedesco Exp $
 *  Release: $Name: glite-data-srm-util-cpp_R_2_0_0_1 $
 *
 */
#ifndef GLITE_DATA_SRM_UTIL_CPP_DETAILS_SYNCHREQUEST_H_
#define GLITE_DATA_SRM_UTIL_CPP_DETAILS_SYNCHREQUEST_H_

#include "glite/data/srm/util/details/Request.h"

namespace glite  {
namespace data   {
namespace srm    {
namespace util   {
namespace details{

/**
 * Abstract Class for SRM Synchronous requests
 */ 
class SynchRequest: public Request {
public: 
    
    // -------------------------------------------------------------------------
    // The SynchRequest class abstract methods
    // -------------------------------------------------------------------------
    
    /**
     * Execute the Request. The result will be stored in the Request's status
     * field. Exception are raised in case of errors. Please note that the 
     * request's failure is not considered an error, therefore exception are 
     * not raised, instead the returned request status and result properties 
     * will be updated accordingly
     * @return the result status 
     * @throw LogicError in case a logic error (e.g. precondityion not met) happens
     * @throw RemoteError in case it cannot contact the remote SRM
     * @throw SecurityError in case a security error happens in contacting the SRM
     * @throw SrmBadResponse in case the SRM returned an inconsistent response
     * @throw SrmError in case it cannot contact the remote SRM
     */
    virtual SrmStatus execute() /* throw (LogicError, RemoteError, SecurityError, SrmBadResponse, SrmError)*/ = 0;
    
protected:
    
    /**
     * destructor
     */
    virtual ~SynchRequest(){}

    
    /**
     * Constructor
     */
    explicit SynchRequest(Context::Ptr ctx):Request(ctx){}
        
private:
    /**
     * Default Constructor. Not Implemented
     */
    SynchRequest();
};

} // End namespace details
} // End namespace util
} // End namespace srm
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_SRM_UTIL_CPP_DETAILS_SYNCHREQUEST_H_
