/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data SRM Util CPP: GSOAP Common functions
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: gsoap-common.h,v 1.8 2008/05/08 12:48:26 ptedesco Exp $
 *  Release: $Name: glite-data-srm-util-cpp_R_2_0_0_1 $
 *
 */
#ifndef GLITE_DATA_SRM_UTIL_CPP_GSOAP_COMMON_H_
#define GLITE_DATA_SRM_UTIL_CPP_GSOAP_COMMON_H_

#include "glite/data/srm/util/SrmExceptions.h"
#include "glite/data/agents/extra/PatternList.h"

/*
 * Include CGSI GSOAP plugin
 */
extern "C"{
#include "cgsi_plugin.h"
}
                                                                                                                                                       
#ifdef __cplusplus
extern "C"{
#endif //__cplusplus
// Fix Warning
#ifdef IOV_MAX
#undef IOV_MAX
#endif //IOV_MAX
#include "globus_gsi_credential.h"
#ifdef __cplusplus
}
#endif //__cplusplus

namespace glite {
namespace data  {
namespace srm   {
namespace util  {

/*
 * Define the function to detect RPC timeout errors
 */	
bool is_TIMEOUT_ERROR(struct soap * soap);
	
/*
 * GSoapContext
 *
 * Constructor
 */
template<typename S> 
void init_soap_ctx(S& ctx,const std::string& endpoint, bool deleg_cred, unsigned long timeout){
    
    ctx.endpoint = endpoint.c_str();
    
    int flags = CGSI_OPT_CLIENT | CGSI_OPT_DISABLE_NAME_CHECK;
    if(true == deleg_cred){
        flags |= CGSI_OPT_DELEG_FLAG;
    }
                                                                                                                                        
    ctx.soap->send_timeout    = timeout;
    ctx.soap->recv_timeout    = timeout;
    ctx.soap->connect_timeout = timeout;
    ctx.soap->accept_timeout  = timeout;
    
    // try avoiding SEGVs on deletion of the soap object..
    static int once = 0;
    if(0 == once){
        globus_module_activate(GLOBUS_GSI_CREDENTIAL_MODULE);
        once = 1;
    }

    // Register cgsi-gsoap plugin
    if(0 == strncasecmp(ctx.endpoint,"https://",8)) {
        flags |= CGSI_OPT_SSL_COMPATIBLE;
        soap_register_plugin_arg (ctx.soap, client_cgsi_plugin, &flags);
    } else if(0 == strncasecmp(ctx.endpoint,"httpg://",8)){
        soap_register_plugin_arg (ctx.soap, client_cgsi_plugin, &flags);
    }
}

std::string get_ip(struct soap * soap);

} // End namespace util
} // End namespace srm
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_SRM_UTIL_CPP_GSOAP_COMMON_H_
